@@ -27,7 +27,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxBlock.cpp 640 2004-07-09 21:05:36Z mosu $
+	\version \$Id: KaxBlock.cpp 984 2004-12-18 22:26:02Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Julien Coloos    <suiryc @ users.sf.net>
 */
@@ -43,7 +43,7 @@
 START_LIBMATROSKA_NAMESPACE
 
 #if MATROSKA_VERSION == 1
-const EbmlSemantic KaxBlockGroup_ContextList[5] =
+const EbmlSemantic KaxBlockGroup_ContextList[6] =
 #else // MATROSKA_VERSION
 const EbmlSemantic KaxBlockGroup_ContextList[8] =
 #endif // MATROSKA_VERSION
@@ -58,11 +58,10 @@ const EbmlSemantic KaxBlockGroup_ContextList[8] =
 	EbmlSemantic(false, false, KaxReferenceBlock::ClassInfos),
 #if MATROSKA_VERSION >= 2
 	EbmlSemantic(false, true,  KaxReferenceVirtual::ClassInfos),
-	EbmlSemantic(false, true,  KaxBlockAdditions::ClassInfos),
 #endif // MATROSKA_VERSION
+	EbmlSemantic(false, true,  KaxBlockAdditions::ClassInfos),
 };
 
-#if MATROSKA_VERSION >= 2
 const EbmlSemantic KaxBlockAdditions_ContextList[1] =
 {
 	EbmlSemantic(true,  false,  KaxBlockMore::ClassInfos)
@@ -73,44 +72,44 @@ const EbmlSemantic KaxBlockMore_ContextList[2] =
 	EbmlSemantic(true,  true,  KaxBlockAddID::ClassInfos),
 	EbmlSemantic(true,  true,  KaxBlockAdditional::ClassInfos)
 };
-#endif // MATROSKA_VERSION
 
 EbmlId KaxBlockGroup_TheId     (0xA0, 1);
 EbmlId KaxBlock_TheId          (0xA1, 1);
 EbmlId KaxBlockDuration_TheId  (0x9B, 1);
 #if MATROSKA_VERSION >= 2
 EbmlId KaxBlockVirtual_TheId   (0xA2, 1);
+#endif // MATROSKA_VERSION
 EbmlId KaxBlockAdditions_TheId (0x75A1, 2);
 EbmlId KaxBlockMore_TheId      (0xA6, 1);
 EbmlId KaxBlockAddID_TheId     (0xEE, 1);
 EbmlId KaxBlockAdditional_TheId(0xA5, 1);
-#endif // MATROSKA_VERSION
 
 const EbmlSemanticContext KaxBlockGroup_Context = EbmlSemanticContext(countof(KaxBlockGroup_ContextList), KaxBlockGroup_ContextList, &KaxCluster_Context, *GetKaxGlobal_Context, &KaxBlockGroup::ClassInfos);
 const EbmlSemanticContext KaxBlock_Context = EbmlSemanticContext(0, NULL, &KaxBlockGroup_Context, *GetKaxGlobal_Context, &KaxBlock::ClassInfos);
 const EbmlSemanticContext KaxBlockDuration_Context = EbmlSemanticContext(0, NULL, &KaxBlockGroup_Context, *GetKaxGlobal_Context, &KaxBlockDuration::ClassInfos);
 #if MATROSKA_VERSION >= 2
 const EbmlSemanticContext KaxBlockVirtual_Context = EbmlSemanticContext(0, NULL, &KaxBlockGroup_Context, *GetKaxGlobal_Context, &KaxBlockVirtual::ClassInfos);
+#endif // MATROSKA_VERSION
 const EbmlSemanticContext KaxBlockAdditions_Context = EbmlSemanticContext(countof(KaxBlockAdditions_ContextList), KaxBlockAdditions_ContextList, &KaxBlockGroup_Context, *GetKaxGlobal_Context, &KaxBlockAdditions::ClassInfos);
 const EbmlSemanticContext KaxBlockMore_Context = EbmlSemanticContext(countof(KaxBlockMore_ContextList), KaxBlockMore_ContextList, &KaxBlockAdditions_Context, *GetKaxGlobal_Context, &KaxBlockMore::ClassInfos);
 const EbmlSemanticContext KaxBlockAddID_Context = EbmlSemanticContext(0, NULL, &KaxBlockMore_Context, *GetKaxGlobal_Context, &KaxBlockAddID::ClassInfos);
 const EbmlSemanticContext KaxBlockAdditional_Context = EbmlSemanticContext(0, NULL, &KaxBlockMore_Context, *GetKaxGlobal_Context, &KaxBlockAdditional::ClassInfos);
-#endif // MATROSKA_VERSION
 
 const EbmlCallbacks KaxBlockGroup::ClassInfos(KaxBlockGroup::Create, KaxBlockGroup_TheId, "BlockGroup", KaxBlockGroup_Context);
 const EbmlCallbacks KaxBlock::ClassInfos(KaxBlock::Create, KaxBlock_TheId, "Block", KaxBlock_Context);
 const EbmlCallbacks KaxBlockDuration::ClassInfos(KaxBlockDuration::Create, KaxBlockDuration_TheId, "BlockDuration", KaxBlockDuration_Context);
 #if MATROSKA_VERSION >= 2
 const EbmlCallbacks KaxBlockVirtual::ClassInfos(KaxBlockVirtual::Create, KaxBlockVirtual_TheId, "BlockVirtual", KaxBlockVirtual_Context);
+#endif // MATROSKA_VERSION
 const EbmlCallbacks KaxBlockAdditions::ClassInfos(KaxBlockAdditions::Create, KaxBlockAdditions_TheId, "BlockAdditions", KaxBlockAdditions_Context);
 const EbmlCallbacks KaxBlockMore::ClassInfos(KaxBlockMore::Create, KaxBlockMore_TheId, "BlockMore", KaxBlockMore_Context);
 const EbmlCallbacks KaxBlockAddID::ClassInfos(KaxBlockAddID::Create, KaxBlockAddID_TheId, "BlockAddID", KaxBlockAddID_Context);
 const EbmlCallbacks KaxBlockAdditional::ClassInfos(KaxBlockAdditional::Create, KaxBlockAdditional_TheId, "BlockAdditional", KaxBlockAdditional_Context);
-#endif // MATROSKA_VERSION
 
 DataBuffer * DataBuffer::Clone()
 {
-	binary *ClonedData = new binary[mySize];
+	binary *ClonedData = (binary *)malloc(mySize * sizeof(binary));
+	assert(ClonedData != NULL);
 	memcpy(ClonedData, myBuffer ,mySize );
 
 	SimpleDataBuffer * result = new SimpleDataBuffer(ClonedData, mySize, 0);
@@ -119,8 +118,9 @@ DataBuffer * DataBuffer::Clone()
 }
 
 SimpleDataBuffer::SimpleDataBuffer(const SimpleDataBuffer & ToClone)
- :DataBuffer(new binary[ToClone.mySize], ToClone.mySize, myFreeBuffer)
+ :DataBuffer((binary *)malloc(ToClone.mySize * sizeof(binary)), ToClone.mySize, myFreeBuffer)
 {
+	assert(myBuffer != NULL);
 	memcpy(myBuffer, ToClone.myBuffer ,mySize );
 	bValidValue = ToClone.bValidValue;
 }
@@ -142,7 +142,6 @@ KaxBlock::KaxBlock(const KaxBlock & ElementToClone)
  ,LocalTimecode(ElementToClone.LocalTimecode)
  ,bLocalTimecodeUsed(ElementToClone.bLocalTimecodeUsed)
  ,TrackNumber(ElementToClone.TrackNumber)
- ,bGap(ElementToClone.bGap)
  ,ParentCluster(ElementToClone.ParentCluster) ///< \todo not exactly
 {
 	// add a clone of the list
@@ -167,7 +166,6 @@ KaxBlockGroup::KaxBlockGroup()
  ,ParentTrack(NULL)
 {}
 
-#if MATROSKA_VERSION >= 2
 KaxBlockAdditions::KaxBlockAdditions()
  :EbmlMaster(KaxBlockAdditions_Context)
 {}
@@ -175,7 +173,6 @@ KaxBlockAdditions::KaxBlockAdditions()
 KaxBlockMore::KaxBlockMore()
  :EbmlMaster(KaxBlockMore_Context)
 {}
-#endif // MATROSKA_VERSION
 
 /*!
 	\todo handle flags
@@ -231,9 +228,6 @@ LacingType KaxBlock::GetBestLacingType() const {
 		return LACING_EBML;
 }
 
-/*!
-	\todo handle gap flag
-*/
 uint64 KaxBlock::UpdateSize(bool bSaveDefault, bool bForceRender)
 {
 	LacingType LacingHere;
@@ -298,9 +292,6 @@ KaxBlockVirtual::KaxBlockVirtual(const KaxBlockVirtual & ElementToClone)
 	Data = DataBlock;
 }
 
-/*!
-	\todo handle the gap flag
-*/
 uint64 KaxBlockVirtual::UpdateSize(bool bSaveDefault, bool bForceRender)
 {
 	assert(TrackNumber < 0x4000);
@@ -319,7 +310,7 @@ uint64 KaxBlockVirtual::UpdateSize(bool bSaveDefault, bool bForceRender)
 	b16.Fill(cursor);
 	cursor += 2;
 
-	*cursor++ = (0 << 0); // no gap
+	*cursor++ = 0; // flags
 
 	return Size;
 }
@@ -363,7 +354,7 @@ uint32 KaxBlock::RenderData(IOCallback & output, bool bForceRender, bool bSaveDe
 		b16.Fill(cursor);
 		cursor += 2;
 
-		*cursor = (0 << 0); // no gap
+		*cursor = 0; // flags
 
 		if (mLacing == LACING_AUTO) {
 			mLacing = GetBestLacingType();
@@ -490,7 +481,6 @@ uint64 KaxBlock::ReadInternalHead(IOCallback & input)
 	bLocalTimecodeUsed = false;
 	cursor += 2;
 
-	bGap = (*cursor && 0x01);
 	return Result;
 }
 
@@ -530,7 +520,6 @@ uint64 KaxBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
 		bLocalTimecodeUsed = true;
 		cursor += 2;
 
-		bGap = (*cursor && 0x01);
 		mLacing = LacingType((*cursor++ & 0x06) >> 1);
 
 		// put all Frames in the list
@@ -633,7 +622,6 @@ uint64 KaxBlock::ReadData(IOCallback & input, ScopeMode ReadFully)
 		bLocalTimecodeUsed = true;
 		cursor += 2;
 
-		bGap = (*cursor && 0x01);
 		mLacing = LacingType((*cursor++ & 0x06) >> 1);
 		if (cursor == &_TempHead[4])
 		{
