@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTag.cpp 717 2004-08-19 08:54:57Z robux4 $
+	\version \$Id: KaxTag.cpp 733 2004-08-27 12:25:01Z robux4 $
 	\author Jory Stone       <jcsston @ toughguy.net>
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
@@ -64,8 +64,9 @@ EbmlSemantic KaxTag_ContextList[14] =
 	EbmlSemantic(true,  false, KaxTagSimple::ClassInfos),
 };
 
-EbmlSemantic KaxTagTargets_ContextList[5] =
+EbmlSemantic KaxTagTargets_ContextList[6] =
 {	
+	EbmlSemantic(false, true,  KaxTagTargetTypeValue::ClassInfos),
 	EbmlSemantic(false, true,  KaxTagTargetType::ClassInfos),
 	EbmlSemantic(false, false, KaxTagTrackUID::ClassInfos),
 	EbmlSemantic(false, false, KaxTagEditionUID::ClassInfos),
@@ -151,6 +152,7 @@ const EbmlSemanticContext KaxTagRating_Context = EbmlSemanticContext(0, NULL, &K
 const EbmlSemanticContext KaxTagSubject_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagSubject::ClassInfos);
 const EbmlSemanticContext KaxTagUnsynchronisedText_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagUnsynchronisedText::ClassInfos);
 const EbmlSemanticContext KaxTagUserDefinedURL_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagUserDefinedURL::ClassInfos);
+const EbmlSemanticContext KaxTagTargetTypeValue_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagTargetTypeValue::ClassInfos);
 const EbmlSemanticContext KaxTagTargetType_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagTargetType::ClassInfos);
 const EbmlSemanticContext KaxTagTrackUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagTrackUID::ClassInfos);
 const EbmlSemanticContext KaxTagEditionUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagEditionUID::ClassInfos);
@@ -210,6 +212,7 @@ EbmlId KaxTagRating_TheId                (0x52BC, 2);
 EbmlId KaxTagSubject_TheId               (0x49C1, 2);
 EbmlId KaxTagUnsynchronisedText_TheId    (0x874B, 2);
 EbmlId KaxTagUserDefinedURL_TheId        (0x434A, 2);
+EbmlId KaxTagTargetTypeValue_TheId       (0x68CA, 2);
 EbmlId KaxTagTargetType_TheId            (0x63CA, 2);
 EbmlId KaxTagTrackUID_TheId              (0x63C5, 2);
 EbmlId KaxTagEditionUID_TheId            (0x63C9, 2);
@@ -275,6 +278,7 @@ const EbmlCallbacks KaxTagRating::ClassInfos(KaxTagRating::Create, KaxTagRating_
 const EbmlCallbacks KaxTagSubject::ClassInfos(KaxTagSubject::Create, KaxTagSubject_TheId, "Subject", KaxTagSubject_Context);
 const EbmlCallbacks KaxTagUnsynchronisedText::ClassInfos(KaxTagUnsynchronisedText::Create, KaxTagUnsynchronisedText_TheId, "UnsynchronisedText", KaxTagUnsynchronisedText_Context);
 const EbmlCallbacks KaxTagUserDefinedURL::ClassInfos(KaxTagUserDefinedURL::Create, KaxTagUserDefinedURL_TheId, "UserDefinedURL", KaxTagUserDefinedURL_Context);
+const EbmlCallbacks KaxTagTargetTypeValue::ClassInfos(KaxTagTargetTypeValue::Create, KaxTagTargetTypeValue_TheId, "TagTargetTypeValue", KaxTagTargetTypeValue_Context);
 const EbmlCallbacks KaxTagTargetType::ClassInfos(KaxTagTargetType::Create, KaxTagTargetType_TheId, "TagTargetType", KaxTagTargetType_Context);
 const EbmlCallbacks KaxTagTrackUID::ClassInfos(KaxTagTrackUID::Create, KaxTagTrackUID_TheId, "TagTrackUID", KaxTagTrackUID_Context);
 const EbmlCallbacks KaxTagEditionUID::ClassInfos(KaxTagEditionUID::Create, KaxTagEditionUID_TheId, "TagEditionUID", KaxTagEditionUID_Context);
