@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTrackVideo.cpp 640 2004-07-09 21:05:36Z mosu $
+	\version \$Id: KaxTrackVideo.cpp 738 2004-08-30 09:21:46Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "matroska/KaxTrackVideo.h"
@@ -40,19 +40,23 @@
 START_LIBMATROSKA_NAMESPACE
 
 #if MATROSKA_VERSION == 1
-const EbmlSemantic KaxTrackVideo_ContextList[6] =
+const EbmlSemantic KaxTrackVideo_ContextList[10] =
 #else // MATROSKA_VERSION
-const EbmlSemantic KaxTrackVideo_ContextList[11] =
+const EbmlSemantic KaxTrackVideo_ContextList[15] =
 #endif // MATROSKA_VERSION
 {
 	EbmlSemantic(true , true, KaxVideoPixelWidth::ClassInfos),
 	EbmlSemantic(true , true, KaxVideoPixelHeight::ClassInfos),
+	EbmlSemantic(false, true, KaxVideoPixelCropBottom::ClassInfos),
+	EbmlSemantic(false, true, KaxVideoPixelCropTop::ClassInfos),
+	EbmlSemantic(false, true, KaxVideoPixelCropLeft::ClassInfos),
+	EbmlSemantic(false, true, KaxVideoPixelCropRight::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoDisplayWidth::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoDisplayHeight::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoColourSpace::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoFrameRate::ClassInfos),
 #if MATROSKA_VERSION >= 2
-	EbmlSemantic(false, true, KaxVideoFlagInterlaced::ClassInfos),
+	EbmlSemantic(true , true, KaxVideoFlagInterlaced::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoStereoMode::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoDisplayUnit::ClassInfos),
 	EbmlSemantic(false, true, KaxVideoAspectRatio::ClassInfos),
@@ -63,6 +67,10 @@ const EbmlSemantic KaxTrackVideo_ContextList[11] =
 const EbmlSemanticContext KaxTrackVideo_Context = EbmlSemanticContext(countof(KaxTrackVideo_ContextList), KaxTrackVideo_ContextList, &KaxTrackEntry_Context, *GetKaxGlobal_Context, &KaxTrackVideo::ClassInfos);
 const EbmlSemanticContext KaxVideoPixelWidth_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelWidth::ClassInfos);
 const EbmlSemanticContext KaxVideoPixelHeight_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelHeight::ClassInfos);
+const EbmlSemanticContext KaxVideoPixelCropBottom_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelCropBottom::ClassInfos);
+const EbmlSemanticContext KaxVideoPixelCropTop_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelCropTop::ClassInfos);
+const EbmlSemanticContext KaxVideoPixelCropRight_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelCropLeft::ClassInfos);
+const EbmlSemanticContext KaxVideoPixelCropLeft_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoPixelCropRight::ClassInfos);
 const EbmlSemanticContext KaxVideoDisplayWidth_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoDisplayWidth::ClassInfos);
 const EbmlSemanticContext KaxVideoDisplayHeight_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoDisplayHeight::ClassInfos);
 const EbmlSemanticContext KaxVideoColourSpace_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoColourSpace::ClassInfos);
@@ -75,24 +83,32 @@ const EbmlSemanticContext KaxVideoAspectRatio_Context = EbmlSemanticContext(0, N
 const EbmlSemanticContext KaxVideoGamma_Context = EbmlSemanticContext(0, NULL, &KaxTrackVideo_Context, *GetKaxGlobal_Context, &KaxVideoGamma::ClassInfos);
 #endif // MATROSKA_VERSION
 
-EbmlId KaxTrackVideo_TheId         (0xE0, 1);
-EbmlId KaxVideoPixelWidth_TheId    (0xB0, 1);
-EbmlId KaxVideoPixelHeight_TheId   (0xBA, 1);
-EbmlId KaxVideoDisplayWidth_TheId  (0x54B0, 2);
-EbmlId KaxVideoDisplayHeight_TheId (0x54BA, 2);
-EbmlId KaxVideoColourSpace_TheId   (0x2EB524, 3);
-EbmlId KaxVideoFrameRate_TheId     (0x2383E3, 3);
+EbmlId KaxTrackVideo_TheId          (0xE0, 1);
+EbmlId KaxVideoPixelWidth_TheId     (0xB0, 1);
+EbmlId KaxVideoPixelHeight_TheId    (0xBA, 1);
+EbmlId KaxVideoPixelCropBottom_TheId(0x54AA, 2);
+EbmlId KaxVideoPixelCropTop_TheId   (0x54BB, 2);
+EbmlId KaxVideoPixelCropLeft_TheId  (0x54CC, 2);
+EbmlId KaxVideoPixelCropRight_TheId (0x54DD, 2);
+EbmlId KaxVideoDisplayWidth_TheId   (0x54B0, 2);
+EbmlId KaxVideoDisplayHeight_TheId  (0x54BA, 2);
+EbmlId KaxVideoColourSpace_TheId    (0x2EB524, 3);
+EbmlId KaxVideoFrameRate_TheId      (0x2383E3, 3);
 #if MATROSKA_VERSION >= 2
-EbmlId KaxVideoFlagInterlaced_TheId(0x9A, 1);
-EbmlId KaxVideoStereoMode_TheId    (0x53B9, 2);
-EbmlId KaxVideoDisplayUnit_TheId   (0x54B2, 2);
-EbmlId KaxVideoAspectRatio_TheId   (0x54B3, 1);
-EbmlId KaxVideoGamma_TheId         (0x2FB523, 3);
+EbmlId KaxVideoFlagInterlaced_TheId (0x9A, 1);
+EbmlId KaxVideoStereoMode_TheId     (0x53B9, 2);
+EbmlId KaxVideoDisplayUnit_TheId    (0x54B2, 2);
+EbmlId KaxVideoAspectRatio_TheId    (0x54B3, 1);
+EbmlId KaxVideoGamma_TheId          (0x2FB523, 3);
 #endif // MATROSKA_VERSION
 
 const EbmlCallbacks KaxTrackVideo::ClassInfos(KaxTrackVideo::Create, KaxTrackVideo_TheId, "TrackAudio", KaxTrackVideo_Context);
 const EbmlCallbacks KaxVideoPixelWidth::ClassInfos(KaxVideoPixelWidth::Create, KaxVideoPixelWidth_TheId, "VideoPixelWidth", KaxVideoPixelWidth_Context);
 const EbmlCallbacks KaxVideoPixelHeight::ClassInfos(KaxVideoPixelHeight::Create, KaxVideoPixelHeight_TheId, "VideoPixelHeight", KaxVideoPixelHeight_Context);
+const EbmlCallbacks KaxVideoPixelCropBottom::ClassInfos(KaxVideoPixelCropBottom::Create, KaxVideoPixelCropBottom_TheId, "VideoPixelCropBottom", KaxVideoPixelCropBottom_Context);
+const EbmlCallbacks KaxVideoPixelCropTop::ClassInfos(KaxVideoPixelCropTop::Create, KaxVideoPixelCropTop_TheId, "VideoPixelCropTop", KaxVideoPixelCropTop_Context);
+const EbmlCallbacks KaxVideoPixelCropLeft::ClassInfos(KaxVideoPixelCropLeft::Create, KaxVideoPixelCropLeft_TheId, "VideoPixelCropLeft", KaxVideoPixelCropLeft_Context);
+const EbmlCallbacks KaxVideoPixelCropRight::ClassInfos(KaxVideoPixelCropRight::Create, KaxVideoPixelCropRight_TheId, "VideoPixelCropRight", KaxVideoPixelCropRight_Context);
 const EbmlCallbacks KaxVideoDisplayWidth::ClassInfos(KaxVideoDisplayWidth::Create, KaxVideoDisplayWidth_TheId, "VideoDisplayWidth", KaxVideoDisplayWidth_Context);
 const EbmlCallbacks KaxVideoDisplayHeight::ClassInfos(KaxVideoDisplayHeight::Create, KaxVideoDisplayHeight_TheId, "VideoDisplayHeight", KaxVideoDisplayHeight_Context);
 const EbmlCallbacks KaxVideoColourSpace::ClassInfos(KaxVideoColourSpace::Create, KaxVideoColourSpace_TheId, "VideoColourSpace", KaxVideoColourSpace_Context);
