@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTracks.cpp 640 2004-07-09 21:05:36Z mosu $
+	\version \$Id: KaxTracks.cpp 1060 2005-01-31 13:39:28Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "matroska/KaxTracks.h"
@@ -49,23 +49,25 @@ const EbmlSemantic KaxTracks_ContextList[1] =
 };
 
 #if MATROSKA_VERSION == 1
-const EbmlSemantic KaxTrackEntry_ContextList[17] =
+const EbmlSemantic KaxTrackEntry_ContextList[21] =
 #else // MATROSKA_VERSION
-const EbmlSemantic KaxTrackEntry_ContextList[23] =
+const EbmlSemantic KaxTrackEntry_ContextList[26] =
 #endif // MATROSKA_VERSION
 {
 	EbmlSemantic(true , true, KaxTrackNumber::ClassInfos),
 	EbmlSemantic(true , true, KaxTrackUID::ClassInfos),
 	EbmlSemantic(true , true, KaxTrackType::ClassInfos),
 #if MATROSKA_VERSION >= 2
-	EbmlSemantic(false, true, KaxTrackFlagEnabled::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackFlagEnabled::ClassInfos),
 #endif // MATROSKA_VERSION
-	EbmlSemantic(false, true, KaxTrackFlagDefault::ClassInfos),
-	EbmlSemantic(false, true, KaxTrackFlagLacing::ClassInfos),
-	EbmlSemantic(true,  true, KaxTrackMinCache::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackFlagDefault::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackFlagForced::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackFlagLacing::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackMinCache::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackMaxCache::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackDefaultDuration::ClassInfos),
-	EbmlSemantic(true,  true, KaxTrackTimecodeScale::ClassInfos),
+	EbmlSemantic(true , true, KaxTrackTimecodeScale::ClassInfos),
+	EbmlSemantic(true , true, KaxMaxBlockAdditionID::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackName::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackLanguage::ClassInfos),
 	EbmlSemantic(true , true, KaxCodecID::ClassInfos),
@@ -73,11 +75,12 @@ const EbmlSemantic KaxTrackEntry_ContextList[23] =
 	EbmlSemantic(false, true, KaxCodecName::ClassInfos),
 #if MATROSKA_VERSION >= 2
 	EbmlSemantic(false, true, KaxCodecSettings::ClassInfos),
-	EbmlSemantic(false, true, KaxCodecInfoURL::ClassInfos),
-	EbmlSemantic(false, true, KaxCodecDownloadURL::ClassInfos),
-	EbmlSemantic(false, true, KaxCodecDecodeAll::ClassInfos),
-	EbmlSemantic(false, true, KaxTrackOverlay::ClassInfos),
+	EbmlSemantic(false, false,KaxCodecInfoURL::ClassInfos),
+	EbmlSemantic(false, false,KaxCodecDownloadURL::ClassInfos),
+	EbmlSemantic(true , true, KaxCodecDecodeAll::ClassInfos),
 #endif // MATROSKA_VERSION
+	EbmlSemantic(false, false,KaxTrackOverlay::ClassInfos),
+	EbmlSemantic(false, false,KaxTrackTranslate::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackAudio::ClassInfos),
 	EbmlSemantic(false, true, KaxTrackVideo::ClassInfos),
 	EbmlSemantic(false, true, KaxContentEncodings::ClassInfos),
